@@ -27,7 +27,12 @@ import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-stepfunctions-tasks", "1.47.1", __name__[0:-6], "aws-stepfunctions-tasks@1.47.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-stepfunctions-tasks",
+    "1.53.0",
+    __name__[0:-6],
+    "aws-stepfunctions-tasks@1.53.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
